#include <gammu.h>

extern void PlayRingtone(int argc, char *argv[]);
extern void CheckFirmware(int argc, char *argv[]);
extern void GetLocation(int argc, char *argv[]);
extern void Identify(int argc, char *argv[]);
extern void NetworkInfo(int argc, char *argv[]);
extern void Monitor(int argc, char *argv[]);
extern void GetRingtone(int argc, char *argv[]);
extern void GetRingtonesList(int argc, char *argv[]);
extern void DialVoice(int argc, char *argv[]);
extern void MakeTerminatedCall(int argc, char *argv[]);
extern void CancelCall(int argc, char *argv[]);
extern void AnswerCall(int argc, char *argv[]);
extern void UnholdCall(int argc, char *argv[]);
extern void HoldCall(int argc, char *argv[]);
extern void ConferenceCall(int argc, char *argv[]);
extern void SplitCall(int argc, char *argv[]);
extern void SwitchCall(int argc, char *argv[]);
extern void TransferCall(int argc, char *argv[]);
extern void Reset(int argc, char *argv[]);
extern void GetWAPBookmark(int argc, char *argv[]);
extern void DeleteWAPBookmark(int argc, char *argv[]);
extern void GetGPRSPoint(int argc, char *argv[]);
extern void GetBitmap(int argc, char *argv[]);
extern void SetBitmap(int argc, char *argv[]);
extern void SetRingtone(int argc, char *argv[]);
extern void ClearAll(int argc, char *argv[]);
extern void GetSyncMLSettings(int argc, char *argv[]);
extern void GetChatSettings(int argc, char *argv[]);
extern void GetWAPMMSSettings(int argc, char *argv[]);
extern void CopyBitmap(int argc, char *argv[]);
extern void CopyRingtone(int argc, char *argv[]);
extern void SetPower(int argc, char *argv[]);
extern void PressKeySequence(int argc, char *argv[]);
extern void GetAllCategories(int argc, char *argv[]);
extern void GetCategory(int argc, char *argv[]);
extern void AddCategory(int argc, char *argv[]);
extern void GetSecurityStatus(int argc, char *argv[]);
extern void EnterSecurityCode(int argc, char *argv[]);
extern void GetProfile(int argc, char *argv[]);
extern void GetSpeedDial(int argc, char *argv[]);
extern void ResetPhoneSettings(int argc, char *argv[]);
extern void SendDTMF(int argc, char *argv[]);
extern void GetDisplayStatus(int argc, char *argv[]);
extern void SetAutoNetworkLogin(int argc, char *argv[]);
extern void GetFMStation(int argc, char *argv[]);
extern void CallDivert(int argc, char *argv[]);
extern void CancelAllDiverts(int argc, char *argv[]);
extern GSM_Error GSM_PlayRingtone(GSM_Ringtone *ringtone);
extern void Battery(int argc, char *argv[]);
extern void Screenshot(int argc, char *argv[]);
extern void Install(int argc, char *argv[]);
